.. networking-midonet documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to networking-midonet's documentation!
==============================================

Networking-midonet is a set of Neutron plugins and drivers for MidoNet.


Supported features
------------------
.. toctree::
   :maxdepth: 2

   user/features

Installation
------------
.. toctree::
   :maxdepth: 2

   install/installation
   install/history
   install/ml2_migration
   install/upgrade

Configuration options
---------------------
.. toctree::
   :maxdepth: 2

   configuration/index

Contributor Guide
-----------------
.. toctree::
   :maxdepth: 2

   contributor/index

References
----------
.. toctree::
   :maxdepth: 2

   reference/specs/index


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

